
################################
### Jan Plue & Alistair Auffret
### September 2020
### R code for analysis of seed bank and vegetation patterns along a European climate and land-cover gradient

## Load packages
library(lme4) # models
library(visreg) # interpretation of interactions
library(maps) # figures
library(scales) # figures

## Read in data
sb<-read.csv("europe.sb.plots.csv", stringsAsFactors = FALSE)

##############
## Summary data
nrow(sb) # 2796 plots
length(unique(sb$dataset)) # 54 datasets


##############
## Species-area relationships - Table S2

# First we make transformation of Raup-Crick and Chao similiarities due to high numbers of zeroes and ones

for(i in unique(sb$dataset)) {
  sb.i<-sb[sb$dataset == i,]
  
  sb.i.chaotemp<-(sb.i$chao*(nrow(sb.i)-1) + 0.5) / nrow(sb.i)
  sb$chao.tr[sb$dataset==i]<-qlogis(sb.i.chaotemp)
  
  sb.i.rauptemp<-(sb.i$raupcrick*(nrow(sb.i)-1) + 0.5) / nrow(sb.i)
  sb$raupcrick.tr[sb$dataset==i]<-qlogis(sb.i.rauptemp)
  
  sb$plot[sb$dataset==i]<-1:nrow(sb.i)
}

# vegetation - all plots
summary(glm(vg.rich ~ log(vg.area), data = sb))$coefficients
# vegetation - per land-use category (1= Open, 2= Transitional, 3= Forest)
lapply(1:3, function(x) summary(glm(vg.rich ~ log(vg.area), data = sb[sb$land.use==x,]))$coefficients)

# seed bank - all plots
summary(glm(sb.rich ~ log(sb.area), data = sb))$coefficients
# seed bank - per land-use category
lapply(1:3, function(x) summary(glm(sb.rich ~ log(sb.area), data = sb[sb$land.use==x,]))$coefficients)

# total richness - all plots
summary(glm(to.rich ~ log(vg.area)*log(sb.area), data = sb))$coefficients
# total richness - per land-use category
lapply(1:3, function(x) summary(glm(to.rich ~ log(vg.area)*log(sb.area), data = sb[sb$land.use==x,]))$coefficients)

# Jaccard similarity - all plots. We scale Y axis for similarity metrics to allow comparison across metrics following transformation of raup and chao. Not logged because no SAR.
summary(glm(scale(jaccard) ~ vg.area*sb.area, data = sb))$coefficients
# Jaccard similarity - per land-use category
lapply(1:3, function(x) summary(glm(scale(jaccard) ~ vg.area*sb.area, data = sb[sb$land.use==x,]))$coefficients)

# Bray-Curtis similarity - all plots.
summary(glm(scale(bray) ~ vg.area*sb.area, data = sb))$coefficients
# Bray-Curtis similarity - per land-use category
lapply(1:3, function(x) summary(glm(scale(bray) ~ vg.area*sb.area, data = sb[sb$land.use==x,]))$coefficients)

# Chao similarity - all plots.
summary(glm(scale(chao.tr) ~ vg.area*sb.area, data = sb))$coefficients
# Chao similarity - per land-use category
lapply(1:3, function(x) summary(glm(scale(chao.tr) ~ vg.area*sb.area, data = sb[sb$land.use==x,]))$coefficients)

# Raup-Crick similarity - all plots.
summary(glm(scale(raupcrick.tr) ~ vg.area*sb.area, data = sb))$coefficients
# Raup-Crick similarity - per land-use category
lapply(1:3, function(x) summary(glm(scale(raupcrick.tr) ~ vg.area*sb.area, data = sb[sb$land.use==x,]))$coefficients)


##############
## Effect of climate and land use

res.list<-list() # create list for empty results

# First extract residuals of temp/latitude model.
sb$lat.rd <- residuals(glm(sb$lat~sb$avg.t.ann))

# Now create land use as factor, so that it is treated as a categorical variable in the analysis
sb$land.use.cat<-as.factor(sb$land.use)
sb$land.use.cat<-relevel(sb$land.use.cat, ref="2") # Assign intermediate habitats as base factor

# Now because we want the scaled X and Y, create a scaled dataset
sb.num.cols<-sapply(sb, is.numeric) # identify numeric columns
sb.scaled<-sb # copy data frame
sb.scaled[,sb.num.cols]<-scale(sb.scaled[,sb.num.cols]) # scale numeric columns


### VEGETATION RICHNESS. Area transformed as log+1 used because of scaling (rather than just log)
m1 <- lmer(vg.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2+lat.rd + log(vg.area+1) + (1|dataset), data = sb.scaled)
sar.offset<-summary(m1)$coefficients["log(vg.area + 1)","Estimate"]

m2<- lmer(vg.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2 + lat.rd + (1|dataset), offset=log((vg.area+1)^sar.offset), data = sb.scaled)
(m2.ci<-confint(m2))

# Exploring significant interactions
# average temperature and temperature range
visreg(m2, "rng.t.ann", by = "avg.t.ann", ylab = "Vegetation species richness", xlab = "Annual temperature range", type = c("contrast"))

# land use (both open and forest) and temperature range
visreg(m2, "rng.t.ann", by = "land.use.cat", ylab = "Vegetation species richness", xlab = "Annual temperature range", type = c("contrast"))

# land use (open only) and precipitation
visreg(m2, "tot.p.ann", by = "land.use.cat", ylab = "Vegetation species richness", xlab = "Annual precipitation")

# write model outputs to list
res.list[["vg.rich"]]<-cbind(rownames(summary(m2)$coefficients), summary(m2)$coefficients, m2.ci[3:nrow(m2.ci),])


### SEED BANK RICHNESS
m1 <- lmer(sb.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2+lat.rd + log(sb.area+1) + (1|dataset), data = sb.scaled)
sar.offset<-summary(m1)$coefficients["log(sb.area + 1)","Estimate"]

m2<- lmer(sb.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2 + lat.rd + (1|dataset), offset=log((sb.area+1)^sar.offset), data = sb.scaled)
(m2.ci<-confint(m2))

# Exploring significant interactions
# annual temperature and precipitation
visreg(m2, "avg.t.ann", by = "tot.p.ann", ylab = "Seed bank species richness", xlab = "Mean annual temperature", type = c("contrast"))

# write model outputs to list
res.list[["sb.rich"]]<-cbind(rownames(summary(m2)$coefficients), summary(m2)$coefficients, m2.ci[3:nrow(m2.ci),])


### TOTAL RICHNESS
m1 <- lmer(to.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2+lat.rd + log(sb.area+1) + log(vg.area+1) + (1|dataset), data = sb.scaled)
sar.offset.vg<-summary(m1)$coefficients["log(vg.area + 1)","Estimate"]
sar.offset.sb<-summary(m1)$coefficients["log(sb.area + 1)","Estimate"]

m2<- lmer(to.rich ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2 + lat.rd + offset(log((sb.area+1)^sar.offset.sb)) + offset(log((vg.area+1)^sar.offset.vg)) + (1|dataset), data = sb.scaled)
(m2.ci<-confint(m2))

# Exploring significant interactions
# annual temperature and temperature range
visreg(m2, "avg.t.ann", by = "rng.t.ann", ylab = "Total species richness", xlab = "Annual temperature", type = c("contrast"))

# temperature and precipitation
visreg(m2, "avg.t.ann", by = "tot.p.ann", ylab = "Total species richness", xlab = "Annual temperature", type = c("contrast"))

# land use and range (open)
visreg(m2, "rng.t.ann", by = "land.use.cat", ylab = "Total species richness", xlab = "Annual temperature range", type = c("contrast"))

# write model outputs to list
res.list[["to.rich"]]<-cbind(rownames(summary(m2)$coefficients), summary(m2)$coefficients, m2.ci[3:nrow(m2.ci),])


### RAUP-CRICK SIMILARITY
sb$rc.samp.eff<-qlogis((sb$sb.area+1)/(sb$vg.area+1)) # calculate sampling area ratio (from unscaled df)
sb.num.cols<-sapply(sb, is.numeric) # identify numeric columns
sb.scaled.raup<-sb[!is.infinite(sb$rc.samp.eff),] # copy data frame, this time removing two rows where vegetation and seed bank sampling area is identical, causing error in scaling
sb.scaled.raup[,sb.num.cols]<-scale(sb.scaled.raup[,sb.num.cols]) # scale numeric columns for new scaled df

m1 <- lmer(raupcrick.tr ~ (land.use.cat+avg.t.ann+tot.p.ann+rng.t.ann)^2 + lat.rd + (1|dataset), offset=rc.samp.eff, data = sb.scaled.raup)
(m1.ci<-confint(m1))

res.list[["raupcrick"]]<-cbind(rownames(summary(m1)$coefficients), summary(m1)$coefficients, m1.ci[3:nrow(m1.ci),])


## Results list can be bound together and written to file (Table S3)
res.df<-data.frame(do.call(rbind,res.list))
res.df$mod<-rep(c("vg.rich","sb.rich", "to.rich","raupcrick"),each=16)
write.csv(res.df,"sb.glmmresults.csv", row.names=FALSE)



########################
## FIGURES

## Fig. 1a - map (Whittaker plot 1b was created manually)

#pdf("Fig1.pdf",width=5, height=5.5,useDingbats=F)
europe<- c("Austria","Belarus","Belgium","Bulgaria","Croatia","Cyprus",
           "Czech Rep.","Denmark","Estonia","Finland","France",
           "Germany","Greece","Hungary","Ireland","Italy","Latvia",
           "Lithuania","Luxembourg","Malta","Netherlands","Norway","Poland",
           "Portugal","Romania","Slovakia","Slovenia","Spain",
           "Sweden", "Switzerland","Ukraine","UK","Kaliningrad","Albania","Kosovo","Serbia","Bosnia","Montenegro","Albania")
map("world", europe, mar = c(0,0,5,0), myborder = 0.01, ylim = c(35,70))
map("world",c("Turkey","Russia"),add=TRUE)

points(sb$long[sb$land.use==3],sb$lat[sb$land.use==3],col=alpha("forestgreen",0.4), pch=17, cex=1.4)
points(sb$long[sb$land.use==1],sb$lat[sb$land.use==1],col=alpha("navyblue",0.4), pch=15, cex=1.3)
points(sb$long[sb$land.use==2],sb$lat[sb$land.use==2],col=alpha("gold",0.4), pch=16, cex=1.2)

legend(-10,67, c("Grassland", "Transitional", "Forest"), pch=15:17, col=alpha(c("navyblue","gold","forestgreen")), bty="n", cex=1.2)

map.axes(cex.axis = 0.8)
map.scale(0, 36.5, ratio = FALSE, cex = 0.8)

# dev.off()


## Fig 2 - species area relationships
#pdf("Fig2.pdf",width=12, height=4,useDingbats=F)

par(mfrow=c(1,3))

sb.hab<-sb[sb$land.use==1,] # subset by land-cover category
min.sb<-min(log(sb.hab$sb.area)) # smallest seed-bank area
max.sb<-max(log(sb.hab$sb.area)) # largest seed-bank area
m.sb.int<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[1] # seed bank SAR regression intercept
m.sb.slo<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[2] # seed bank SAR regression slope

min.vg<-min(log(sb.hab$vg.area)) # same for vegetation
max.vg<-max(log(sb.hab$vg.area))
m.vg.int<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[1]
m.vg.slo<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[2]

plot(c(vg.rich,sb.rich)~c(log(vg.area),log(sb.area)), data=sb, type="n", xlab="Logged plot size", ylab="Species richness", bty="n", cex.lab=1.4) # empty plot
title("a) Open habitat") # title
points(sb.rich~log(sb.area),data=sb.hab, col=alpha("dodgerblue4",0.2), lwd=2) # add seed bank plots
segments(min.sb, m.sb.int+(m.sb.slo*min.sb), max.sb, m.sb.int+(m.sb.slo*max.sb), col="dodgerblue4", lwd=3, lty=2) # add regression line through seed bank data
segments(max.sb, m.sb.int+(m.sb.slo*max.sb), max.vg, m.sb.int+(m.sb.slo*max.vg), col="dimgrey", lwd=3, lty=3) # extend regression line through vegetation  data

points(vg.rich~log(vg.area),data=sb.hab, col=alpha("dodgerblue4",0.2), pch=16)
segments(min.vg, m.vg.int+(m.vg.slo*min.vg), max.vg, m.vg.int+(m.vg.slo*max.vg), col="dodgerblue4", lwd=3, lty=1)
segments(min.sb, m.vg.int+(m.vg.slo*min.sb), min.vg, m.vg.int+(m.vg.slo*min.vg), col="dimgrey", lwd=3, lty=3)
legend(-6.75,60,c("Seed bank", "Herb layer"), pch=c(1,16), col=alpha("dodgerblue4",0.8),cex=1.2,bty="n")


sb.hab<-sb[sb$land.use==2,]
min.sb<-min(log(sb.hab$sb.area))
max.sb<-max(log(sb.hab$sb.area))
m.sb.int<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[1]
m.sb.slo<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[2]

min.vg<-min(log(sb.hab$vg.area))
max.vg<-max(log(sb.hab$vg.area))
m.vg.int<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[1]
m.vg.slo<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[2]

plot(c(vg.rich,sb.rich)~c(log(vg.area),log(sb.area)), data=sb, type="n", xlab="Logged plot size", ylab="Species richness", bty="n", cex.lab=1.4)
title("b) Transitional habitat")
points(sb.rich~log(sb.area),data=sb.hab, col=alpha("darkorange",0.2), lwd=2)
segments(min.sb, m.sb.int+(m.sb.slo*min.sb), max.sb, m.sb.int+(m.sb.slo*max.sb), col="darkorange", lwd=3, lty=2)
segments(max.sb, m.sb.int+(m.sb.slo*max.sb), max.vg, m.sb.int+(m.sb.slo*max.vg), col="dimgrey", lwd=3, lty=3)

points(vg.rich~log(vg.area),data=sb.hab, col=alpha("darkorange",0.2), pch=16)
segments(min.vg, m.vg.int+(m.vg.slo*min.vg), max.vg, m.vg.int+(m.vg.slo*max.vg), col="darkorange", lwd=3, lty=1)
segments(min.sb, m.vg.int+(m.vg.slo*min.sb), min.vg, m.vg.int+(m.vg.slo*min.vg), col="dimgrey", lwd=3, lty=3)


sb.hab<-sb[sb$land.use==3,]
min.sb<-min(log(sb.hab$sb.area))
max.sb<-max(log(sb.hab$sb.area))
m.sb.int<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[1]
m.sb.slo<-lm(sb.rich~log(sb.area),data=sb.hab)$coefficients[2]

min.vg<-min(log(sb.hab$vg.area))
max.vg<-max(log(sb.hab$vg.area))
m.vg.int<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[1]
m.vg.slo<-lm(vg.rich~log(vg.area),data=sb.hab)$coefficients[2]

plot(c(vg.rich,sb.rich)~c(log(vg.area),log(sb.area)), data=sb, type="n", xlab="Logged plot size", ylab="Species richness", bty="n", cex.lab=1.4)
title("c) Forest habitat")
points(sb.rich~log(sb.area),data=sb.hab, col=alpha("forestgreen",0.2), lwd=2)
segments(min.sb, m.sb.int+(m.sb.slo*min.sb), max.sb, m.sb.int+(m.sb.slo*max.sb), col="forestgreen", lwd=3, lty=2)
segments(max.sb, m.sb.int+(m.sb.slo*max.sb), max.vg, m.sb.int+(m.sb.slo*max.vg), col="dimgrey", lwd=3, lty=3)

points(vg.rich~log(vg.area),data=sb.hab, col=alpha("forestgreen",0.2), pch=16)
segments(min.vg, m.vg.int+(m.vg.slo*min.vg), max.vg, m.vg.int+(m.vg.slo*max.vg), col="forestgreen", lwd=3, lty=1)
segments(min.sb, m.vg.int+(m.vg.slo*min.sb), min.vg, m.vg.int+(m.vg.slo*min.vg), col="dimgrey", lwd=3, lty=3)

dev.off()


## Fig. 3 - model outputs
res.df<-read.csv("sb.glmmresults.csv", stringsAsFactors = FALSE) # read in results df again. Most straightforward to do this as do.call() converts numeric into factors, but this way imports them back as numeric

#pdf("Fig3.pdf", width = 12, height = 4)

par(mfrow=c(1,4))

mod<-res.df[res.df$mod=="vg.rich",]
mod$text<-c("INTERCEPT","LC-Open", "LC-Forest", "Temp","Prec","Range","Lat","LC-O:T", "LC-F:T","LC-O:P", "LC-F:P", "LC-O:R", "LC-F:R", "T:P","T:R", "P:R") # add label text to df
sig.ints<-which(sign(mod[8:16,"X2.5.."]) == sign(mod[8:16,"X97.5.."])) + 7 # Identify significant interactions and add 7 (number of rows up until interaction terms)
mod<-mod[c(2:7,sig.ints),] # subset df so only single predictors and significant interactions are left
mod$col[sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"black" # create column with black for significant
mod$col[!sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"darkgrey" # ... and grey for non-significant parameters

plot(0,xlim=c(0,nrow(mod)+1.5),ylim=c(-1,1),type="n", axes=FALSE, ann=FALSE) # create empty plot
polygon(c(7,nrow(mod)+2,nrow(mod)+2,7),c(-1.5,-1.5,1.5,1.5),col="grey95", lty=0) # draw polygon to clearly distinguish single predictors from interactions
abline(0,0, lty=1, lwd=2) # add line at Y=0
abline(0.2,0, lty=2, lwd=2, col="grey") # add lines at Y=0.2 and -0.2 to indicate effect strength
abline(-0.2,0, lty=2, lwd=2, col="grey")
segments(c(1:6,8:(7+length(sig.ints))),mod$X2.5..,c(1:6,8:(7+length(sig.ints))),mod$X97.5.., col=mod$col, lwd=2) # draw lines for confidence intervals
points(c(1:6,8:(7+length(sig.ints))),mod$Estimate, col=mod$col, pch=21,bg="white",cex=1, lwd=2) # add points for Estimates
mtext(mod$text,side=1, at=c(1:6,8:(7+length(sig.ints))), line=0, cex=0.8, las = 2) # add X labels
axis(2,lwd=2) 
mtext("Standardized effect size", side = 2, line = 2.5, cex = 1) # Y label
title("Herb layer richness") # Add title

mod<-res.df[res.df$mod=="sb.rich",]
mod$text<-c("INTERCEPT","LC-Open", "LC-Forest", "Temp","Prec","Range","Lat","LC-O:T", "LC-F:T","LC-O:P", "LC-F:P", "LC-O:R", "LC-F:R", "T:P","T:R", "P:R")
sig.ints<-which(sign(mod[8:16,"X2.5.."]) == sign(mod[8:16,"X97.5.."])) + 7
mod<-mod[c(2:7,sig.ints),]
mod$col[sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"black"
mod$col[!sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"darkgrey"

plot(0,xlim=c(0,nrow(mod)+1.5),ylim=c(-1,1),type="n", axes=FALSE, ann=FALSE) 
polygon(c(7,nrow(mod)+2,nrow(mod)+2,7),c(-1.5,-1.5,1.5,1.5),col="grey95", lty=0)
abline(0,0, lty=1, lwd=2) 
abline(0.2,0, lty=2, lwd=2, col="grey")
abline(-0.2,0, lty=2, lwd=2, col="grey")
segments(c(1:6,8:(7+length(sig.ints))),mod$X2.5..,c(1:6,8:(7+length(sig.ints))),mod$X97.5.., col=mod$col, lwd=2) # 
points(c(1:6,8:(7+length(sig.ints))),mod$Estimate, col=mod$col, pch=21,bg="white",cex=1, lwd=2) 
mtext(mod$text,side=1, at=c(1:6,8:(7+length(sig.ints))), line=0, cex=0.8, las = 2) 
axis(2,lwd=2) 
mtext("Standardized effect size", side = 2, line = 2.5, cex = 1)
title("Seed bank richness") 

mod<-res.df[res.df$mod=="to.rich",]
mod$text<-c("INTERCEPT","LC-Open", "LC-Forest", "Temp","Prec","Range","Lat","LC-O:T", "LC-F:T","LC-O:P", "LC-F:P", "LC-O:R", "LC-F:R", "T:P","T:R", "P:R")
sig.ints<-which(sign(mod[8:16,"X2.5.."]) == sign(mod[8:16,"X97.5.."])) + 7
mod<-mod[c(2:7,sig.ints),]
mod$col[sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"black"
mod$col[!sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"darkgrey"

plot(0,xlim=c(0,nrow(mod)+1.5),ylim=c(-1,1),type="n", axes=FALSE, ann=FALSE) 
polygon(c(7,nrow(mod)+2,nrow(mod)+2,7),c(-1.5,-1.5,1.5,1.5),col="grey95", lty=0)
abline(0,0, lty=1, lwd=2) # line at zero
abline(0.2,0, lty=2, lwd=2, col="grey")
abline(-0.2,0, lty=2, lwd=2, col="grey")
segments(c(1:6,8:(7+length(sig.ints))),mod$X2.5..,c(1:6,8:(7+length(sig.ints))),mod$X97.5.., col=mod$col, lwd=2) # 
points(c(1:6,8:(7+length(sig.ints))),mod$Estimate, col=mod$col, pch=21,bg="white",cex=1, lwd=2) 
mtext(mod$text,side=1, at=c(1:6,8:(7+length(sig.ints))), line=0, cex=0.8, las = 2) 
axis(2,lwd=2)
mtext("Standardized effect size", side = 2, line = 2.5, cex = 1)
title("Total richness")


mod<-res.df[res.df$mod=="raupcrick",] # had to go in manually as no sig interactions
mod$text<-c("INTERCEPT","LC-Open", "LC-Forest", "Temp","Prec","Range","Lat","LC-O:T", "LC-F:T","LC-O:P", "LC-F:P", "LC-O:R", "LC-F:R", "T:P","T:R", "P:R")
sig.ints<-which(sign(mod[8:16,"X2.5.."]) == sign(mod[8:16,"X97.5.."])) + 7
mod<-mod[c(2:7,sig.ints),]
mod$col[sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"black"
mod$col[!sign(mod$X2.5..) == sign(mod$X97.5..) ]<-"darkgrey"

plot(0,xlim=c(0,nrow(mod)+1),ylim=c(-1,1),type="n", axes=FALSE, ann=FALSE)
abline(0,0, lty=1, lwd=2)
abline(0.2,0, lty=2, lwd=2, col="grey")
abline(-0.2,0, lty=2, lwd=2, col="grey")
segments(1:6,mod$X2.5..,1:6,mod$X97.5.., col=mod$col, lwd=2) 
points(1:6,mod$Estimate, col=mod$col, pch=21,bg="white",cex=1, lwd=2) 
mtext(mod$text,side=1, at=1:6, line=0, cex=0.8, las = 2)
axis(2,lwd=2) 
mtext("Standardized effect size", side = 2, line = 2.5, cex = 1)
title("Raup-Crick similarity")

#ev.off()


